@@ -1,6 +1,11 @@
-from os.path import join
+# -*- coding: utf-8 -*-
+
+import os.path
+
 from django.conf import settings
-from util import filter_blanks, rstrip_str
+
+from pybb.util import filter_blanks, rstrip_str
+
 
 PYBB_TOPIC_PAGE_SIZE = getattr(settings, 'PYBB_TOPIC_PAGE_SIZE', 10)
 PYBB_FORUM_PAGE_SIZE = getattr(settings, 'PYBB_FORUM_PAGE_SIZE', 20)
@@ -17,7 +22,7 @@ PYBB_FREEZE_FIRST_POST = getattr(settings, 'PYBB_FREEZE_FIRST_POST', False)
 
 PYBB_ATTACHMENT_SIZE_LIMIT = getattr(settings, 'PYBB_ATTACHMENT_SIZE_LIMIT', 1024 * 1024)
 PYBB_ATTACHMENT_ENABLE = getattr(settings, 'PYBB_ATTACHMENT_ENABLE', False)
-PYBB_ATTACHMENT_UPLOAD_TO = getattr(settings, 'PYBB_ATTACHMENT_UPLOAD_TO', join('pybb_upload', 'attachments'))
+PYBB_ATTACHMENT_UPLOAD_TO = getattr(settings, 'PYBB_ATTACHMENT_UPLOAD_TO', os.path.join('pybb_upload', 'attachments'))
 
 PYBB_DEFAULT_AVATAR_URL = getattr(settings,'PYBB_DEFAULT_AVATAR_URL',
     getattr(settings, 'STATIC_URL', '') + 'pybb/img/default_avatar.jpg')
@@ -45,9 +50,6 @@ PYBB_SMILES = getattr(settings, 'PYBB_SMILES', {
     ';)': 'wink.png'
 })
 
-#MEDIA_URL = getattr(settings, 'MEDIA_URL', '/media/')
-#STATIC_URL = getattr(settings, 'STATIC_URL', '')
-
 def smile_it(str):
     s = str
     for smile, url in PYBB_SMILES.items():
